# Layrz Protocol

![PyPI - Version](https://img.shields.io/pypi/v/layrz-protocol?style=for-the-badge&logo=python&logoColor=white&cacheSeconds=1)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/layrz-protocol?style=for-the-badge&logo=python&logoColor=white&cacheSeconds=1)
![PyPI - Status](https://img.shields.io/pypi/status/layrz-protocol?style=for-the-badge&logo=python&logoColor=white&cacheSeconds=1)
![PyPI - License](https://img.shields.io/pypi/l/layrz-protocol?style=for-the-badge&cacheSeconds=1)
![PyPI - Implementation](https://img.shields.io/pypi/implementation/layrz-protocol?style=for-the-badge&logo=python&logoColor=white&cacheSeconds=1)
![GitHub License](https://img.shields.io/github/license/goldenm-software/layrz-protocol?style=for-the-badge&logo=github&cacheSeconds=1)

## Description

Is the official Development Kit for Layrz Protocol, allowing to translate all of the packages sent and received by the Layrz Protocol.
Also, includes the the wrapper to send and receive messages from the Layrz Protocol.

## Requirements

This library uses at least Python 3.10 or higher to work.

## Documentation

For more information about the protocol, check out the [Layrz Protocol Documentation](https://developers.layrz.com/protocol/)

## Work with us

Golden M is a software/hardware development company what is working on
a new, innovative and disruptive technologies.

For more information, contact us at [sales@layrz.com](mailto:sales@layrz.com)

## License

This project is under Apache License 2.0

This project is maintained by [Golden M](https://goldenm.com) with authorization of [Layrz LTD](https://layrz.com).

## Who are you? / Want to work with us?

<b>Golden M</b> is a software and hardware development company what is working on a new, innovative and disruptive technologies. For more information, contact us at [sales@goldenm.com](mailto:sales@goldenm.com) or via WhatsApp at [+(507)-6979-3073](https://wa.me/50769793073?text="From%20layrz_models%20flutter%20library.%20Hello").

